@@ -38,7 +38,6 @@ from unittest import mock
 from awscli.compat import StringIO
 
 
-from awscli.compat import six
 from botocore.session import Session
 from botocore.exceptions import ClientError
 from botocore.exceptions import WaiterError
@@ -48,20 +47,13 @@ from botocore.awsrequest import AWSResponse
 import awscli.clidriver
 from awscli.plugin import load_plugins
 from awscli.clidriver import CLIDriver
+from awscli.compat import BytesIO, StringIO
 from awscli import EnvironmentVariables
 
 
 import unittest
 
 
-# In python 3, order matters when calling assertEqual to
-# compare lists and dictionaries with lists. Therefore,
-# assertItemsEqual needs to be used but it is renamed to
-# assertCountEqual in python 3.
-if six.PY2:
-    unittest.TestCase.assertCountEqual = unittest.TestCase.assertItemsEqual
-
-
 _LOADER = botocore.loaders.Loader()
 INTEG_LOG = logging.getLogger('awscli.tests.integration')
 AWS_CMD = None
@@ -160,7 +152,7 @@ def create_bucket(session, name=None, region=None):
         bucket_name = name
     else:
         bucket_name = random_bucket_name()
-    params = {'Bucket': bucket_name}
+    params = {'Bucket': bucket_name, 'ObjectOwnership': 'ObjectWriter'}
     if region != 'us-east-1':
         params['CreateBucketConfiguration'] = {'LocationConstraint': region}
     try:
@@ -289,8 +281,8 @@ class CapturedOutput(object):
 
 @contextlib.contextmanager
 def capture_output():
-    stderr = six.StringIO()
-    stdout = six.StringIO()
+    stderr = StringIO()
+    stdout = StringIO()
     with mock.patch('sys.stderr', stderr):
         with mock.patch('sys.stdout', stdout):
             yield CapturedOutput(stdout, stderr)
@@ -298,12 +290,9 @@ def capture_output():
 
 @contextlib.contextmanager
 def capture_input(input_bytes=b''):
-    input_data = six.BytesIO(input_bytes)
-    if six.PY3:
-        mock_object = mock.Mock()
-        mock_object.buffer = input_data
-    else:
-        mock_object = input_data
+    input_data = BytesIO(input_bytes)
+    mock_object = mock.Mock()
+    mock_object.buffer = input_data
 
     with mock.patch('sys.stdin', mock_object):
         yield input_data
@@ -623,8 +612,6 @@ def aws(command, collect_memory=False, env_vars=None,
         aws_command = 'python %s' % get_aws_cmd()
     full_command = '%s %s' % (aws_command, command)
     stdout_encoding = get_stdout_encoding()
-    if isinstance(full_command, six.text_type) and not six.PY3:
-        full_command = full_command.encode(stdout_encoding)
     INTEG_LOG.debug("Running command: %s", full_command)
     env = os.environ.copy()
     if 'AWS_DEFAULT_REGION' not in env:
@@ -742,7 +729,7 @@ class BaseS3CLICommand(unittest.TestCase):
 
     def assert_key_contents_equal(self, bucket, key, expected_contents):
         self.wait_until_key_exists(bucket, key)
-        if isinstance(expected_contents, six.BytesIO):
+        if isinstance(expected_contents, BytesIO):
             expected_contents = expected_contents.getvalue().decode('utf-8')
         actual_contents = self.get_key_contents(bucket, key)
         # The contents can be huge so we try to give helpful error messages
@@ -752,6 +739,12 @@ class BaseS3CLICommand(unittest.TestCase):
             self.fail("Contents for %s/%s do not match (but they "
                       "have the same length)" % (bucket, key))
 
+    def delete_public_access_block(self, bucket_name):
+        client = self.create_client_for_bucket(bucket_name)
+        client.delete_public_access_block(
+             Bucket=bucket_name
+        )
+
     def create_bucket(self, name=None, region=None):
         if not region:
             region = self.region
@@ -761,6 +754,7 @@ class BaseS3CLICommand(unittest.TestCase):
 
         # Wait for the bucket to exist before letting it be used.
         self.wait_bucket_exists(bucket_name)
+        self.delete_public_access_block(bucket_name)
         return bucket_name
 
     def put_object(self, bucket_name, key_name, contents='', extra_args=None):
@@ -990,3 +984,13 @@ class ConsistencyWaiter(object):
     def _fail_message(self, attempts, successes):
         format_args = (attempts, successes)
         return 'Failed after %s attempts, only had %s successes' % format_args
+
+
+@contextlib.contextmanager
+def cd(path):
+    try:
+        original_dir = os.getcwd()
+        os.chdir(path)
+        yield
+    finally:
+        os.chdir(original_dir)
